@@ -1,11 +1,10 @@
 # ABSTRACT: read mail and send to wiki
 package Mail2Wiki;
-use Moose;
-use YAML::XS 'LoadFile';
-use Module::Runtime 'use_module';
-use File::Slurp;
 use Mail2Wiki::MailClient;
-use Mail2Wiki::Wiki;
+use Moose;
+use Module::Runtime 'use_module';
+use Config::Tiny;
+use File::Slurp;
 use Log::Any '$log';
 use Encode ();
 use utf8;
@@ -14,11 +13,9 @@ has 'config_file' => ( is => 'ro', isa => 'Str', default => 'config' );
 
 has 'config' => (
     is      => 'ro',
-    isa     => 'HashRef',
-    traits  => ['Hash'],
+    isa     => 'Config::Tiny',
     lazy    => 1,
     builder => '_build_config',
-    handles => { get_config => 'get' },
 );
 
 has 'mail_client' => (
@@ -38,31 +35,25 @@ has 'wiki' => (
 sub _build_config {
     my $self = shift;
     -f $self->config_file
-      or die "Config file <", $self->config_file, ">unexist : $!\n";
-    my $conf = LoadFile( $self->config_file );
-    return $conf;
+      or $log->error( "Config file <", $self->config_file, ">unexist : $!" )
+      and exit(1);
+    my $config = Config::Tiny->read( $self->config_file )
+      or $log->error( "read configure file failed: " . Config::Tiny->errstr )
+      and exit(1);
+    return $config;
 }
 
 sub _build_mail_client {
     my $self = shift;
-    return Mail2Wiki::MailClient->new(
-        server => $self->get_config('mail_server') // "",
-        port   => $self->get_config('mail_port')   // 993,
-        user   => $self->get_config('mail_user')   // "",
-        pass   => $self->get_config('mail_pass')   // "",
-    );
+    return Mail2Wiki::MailClient->new( %{ $self->config->{mail} } );
 }
 
 sub _build_wiki {
-    my $self = shift;
-    my $type = $self->get_config('wiki_type');
-    my $wiki = $type ? "Mail2Wiki::Wiki::$type" : "Mail2Wiki::Wiki";
-    return use_module($wiki)->new(
-        domain => $self->get_config('wiki_domain') // "",
-        user   => $self->get_config('wiki_user')   // "",
-        pass   => $self->get_config('wiki_pass')   // "",
-        prefix => $self->get_config('wiki_prefix') // "",
-    );
+    my $self      = shift;
+    my $wiki_type = delete $self->config->{wiki}->{type};
+    return use_module(
+        $wiki_type ? "Mail2Wiki::Wiki::$wiki_type" : "Mail2Wiki::Wiki" )
+      ->new( %{ $self->config->{wiki} } );
 }
 
 sub publish {
@@ -80,6 +71,7 @@ sub publish {
     # Post Wiki
     $log->info('post each mail to wiki ...');
     while ( my $m = $self->mail_client->get_mail ) {
+        $log->info(" posting : " . Encode::encode( 'utf8', $m->subject) );
         eval {
             $self->wiki->post(
                 subject => $m->subject,
@@ -88,11 +80,14 @@ sub publish {
                 poster  => $m->poster,
             );
         }
-          or $log->warn( " post failed of : "
+          or $log->warn( "> post failed of : "
               . Encode::encode( 'utf8', $m->subject )
               . ": $@" );
+        $log->info("> Done.");
     }
     $log->info('post Done ...');
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
