@@ -16,5 +16,7 @@ sub dump {
     return $self;
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
